==> bonita-server-7.1.0-sources.jar: org/bonitasoft/engine/service/impl/SpringPlatformInitServiceAccessor.java <==
/**
 * Copyright (C) 2015 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.service.impl;

import org.bonitasoft.engine.sessionaccessor.SessionAccessor;

/**
 * @author Matthieu Chaffotte
 */
public class SpringPlatformInitServiceAccessor implements SessionAccessorAccessor {

    private static final SessionAccessorAccessor instance = new SpringPlatformInitServiceAccessor();

    private static SessionAccessor sessionAccessor;

    public SpringPlatformInitServiceAccessor() {

    }

    public static SessionAccessorAccessor getInstance() {
        return instance;
    }

    @Override
    public SessionAccessor getSessionAccessor() {
        if (sessionAccessor == null) {
            sessionAccessor = SpringFileSystemBeanAccessorFactory.getPlatformInitAccessor().getService(SessionAccessor.class);
        }
        return sessionAccessor;
    }

    @Override
    public void destroy() {
        SpringFileSystemBeanAccessorFactory.getPlatformInitAccessor().destroy();

    }

}

==> bonita-server-7.3.3-sources.jar: org/bonitasoft/engine/service/impl/SpringPlatformInitServiceAccessor.java <==
/**
 * Copyright (C) 2015 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.service.impl;

import org.bonitasoft.engine.sessionaccessor.SessionAccessor;

/**
 * @author Matthieu Chaffotte
 */
public class SpringPlatformInitServiceAccessor implements PlatformInitServiceAccessor {

    private static final PlatformInitServiceAccessor instance = new SpringPlatformInitServiceAccessor();

    private static SessionAccessor sessionAccessor;

    public SpringPlatformInitServiceAccessor() {

    }

    public static PlatformInitServiceAccessor getInstance() {
        return instance;
    }

    @Override
    public SessionAccessor getSessionAccessor() {
        if (sessionAccessor == null) {
            sessionAccessor = BeanAccessorFactory.getPlatformInitBeanAccessor().getService(SessionAccessor.class);
        }
        return sessionAccessor;
    }

    @Override
    public void destroy() {
        BeanAccessorFactory.getPlatformInitBeanAccessor().destroy();

    }

}
